@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,9 +13,60 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class BindStaffSkillGroupListRequest(AbstractModel):
+    """BindStaffSkillGroupList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 实例ID
+        :type SdkAppId: int
+        :param StaffEmail: 坐席邮箱
+        :type StaffEmail: str
+        :param SkillGroupList: 绑定技能组列表
+        :type SkillGroupList: list of int
+        """
+        self.SdkAppId = None
+        self.StaffEmail = None
+        self.SkillGroupList = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.StaffEmail = params.get("StaffEmail")
+        self.SkillGroupList = params.get("SkillGroupList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class BindStaffSkillGroupListResponse(AbstractModel):
+    """BindStaffSkillGroupList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CreateSDKLoginTokenRequest(AbstractModel):
     """CreateSDKLoginToken请求参数结构体
 
@@ -35,6 +86,13 @@ class CreateSDKLoginTokenRequest(AbstractModel):
     def _deserialize(self, params):
         self.SdkAppId = params.get("SdkAppId")
         self.SeatUserId = params.get("SeatUserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateSDKLoginTokenResponse(AbstractModel):
@@ -90,6 +148,13 @@ class CreateStaffRequest(AbstractModel):
                 obj = SeatUserInfo()
                 obj._deserialize(item)
                 self.Staffs.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateStaffResponse(AbstractModel):
@@ -99,13 +164,73 @@ class CreateStaffResponse(AbstractModel):
 
     def __init__(self):
         """
+        :param ErrorStaffList: 错误坐席列表及错误信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ErrorStaffList: list of ErrStaffItem
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
+        self.ErrorStaffList = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
+        if params.get("ErrorStaffList") is not None:
+            self.ErrorStaffList = []
+            for item in params.get("ErrorStaffList"):
+                obj = ErrStaffItem()
+                obj._deserialize(item)
+                self.ErrorStaffList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DeleteStaffRequest(AbstractModel):
+    """DeleteStaff请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 实例ID
+        :type SdkAppId: int
+        :param StaffList: 待删除客服邮箱列表
+        :type StaffList: list of str
+        """
+        self.SdkAppId = None
+        self.StaffList = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.StaffList = params.get("StaffList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeleteStaffResponse(AbstractModel):
+    """DeleteStaff返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param OnlineStaffList: 无法删除的状态为在线的客服列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OnlineStaffList: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.OnlineStaffList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.OnlineStaffList = params.get("OnlineStaffList")
         self.RequestId = params.get("RequestId")
 
 
@@ -144,6 +269,13 @@ class DescribeChatMessagesRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
         self.Order = params.get("Order")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeChatMessagesResponse(AbstractModel):
@@ -215,6 +347,13 @@ class DescribeIMCdrsRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeIMCdrsResponse(AbstractModel):
@@ -270,6 +409,13 @@ class DescribePSTNActiveSessionListRequest(AbstractModel):
         self.SdkAppId = params.get("SdkAppId")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribePSTNActiveSessionListResponse(AbstractModel):
@@ -325,6 +471,13 @@ class DescribeSeatUserListRequest(AbstractModel):
         self.InstanceId = params.get("InstanceId")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSeatUserListResponse(AbstractModel):
@@ -388,6 +541,13 @@ class DescribeSkillGroupInfoListRequest(AbstractModel):
         self.PageNumber = params.get("PageNumber")
         self.SkillGroupId = params.get("SkillGroupId")
         self.ModifiedTime = params.get("ModifiedTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSkillGroupInfoListResponse(AbstractModel):
@@ -451,6 +611,13 @@ class DescribeStaffInfoListRequest(AbstractModel):
         self.PageNumber = params.get("PageNumber")
         self.StaffMail = params.get("StaffMail")
         self.ModifiedTime = params.get("ModifiedTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeStaffInfoListResponse(AbstractModel):
@@ -506,6 +673,13 @@ class DescribeTelCallInfoRequest(AbstractModel):
         self.StartTimeStamp = params.get("StartTimeStamp")
         self.EndTimeStamp = params.get("EndTimeStamp")
         self.SdkAppIdList = params.get("SdkAppIdList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTelCallInfoResponse(AbstractModel):
@@ -580,6 +754,13 @@ class DescribeTelCdrRequest(AbstractModel):
         self.SdkAppId = params.get("SdkAppId")
         self.PageSize = params.get("PageSize")
         self.PageNumber = params.get("PageNumber")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTelCdrResponse(AbstractModel):
@@ -612,6 +793,89 @@ class DescribeTelCdrResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeTelSessionRequest(AbstractModel):
+    """DescribeTelSession请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 应用ID
+        :type SdkAppId: int
+        :param SessionId: 会话ID
+        :type SessionId: str
+        """
+        self.SdkAppId = None
+        self.SessionId = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.SessionId = params.get("SessionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeTelSessionResponse(AbstractModel):
+    """DescribeTelSession返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Session: 会话信息
+        :type Session: :class:`tencentcloud.ccc.v20200210.models.PSTNSession`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Session = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Session") is not None:
+            self.Session = PSTNSession()
+            self.Session._deserialize(params.get("Session"))
+        self.RequestId = params.get("RequestId")
+
+
+class ErrStaffItem(AbstractModel):
+    """批量添加客服时，返回出错客服的像个信息
+
+    """
+
+    def __init__(self):
+        """
+        :param StaffEmail: 坐席邮箱地址
+        :type StaffEmail: str
+        :param Code: 错误码
+        :type Code: str
+        :param Message: 错误描述
+        :type Message: str
+        """
+        self.StaffEmail = None
+        self.Code = None
+        self.Message = None
+
+
+    def _deserialize(self, params):
+        self.StaffEmail = params.get("StaffEmail")
+        self.Code = params.get("Code")
+        self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class IMCdrInfo(AbstractModel):
     """全媒体服务记录信息
 
@@ -651,6 +915,13 @@ class IMCdrInfo(AbstractModel):
         self.Type = params.get("Type")
         self.StaffId = params.get("StaffId")
         self.Timestamp = params.get("Timestamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IVRKeyPressedElement(AbstractModel):
@@ -674,6 +945,13 @@ class IVRKeyPressedElement(AbstractModel):
     def _deserialize(self, params):
         self.Key = params.get("Key")
         self.Label = params.get("Label")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Message(AbstractModel):
@@ -695,6 +973,13 @@ class Message(AbstractModel):
     def _deserialize(self, params):
         self.Type = params.get("Type")
         self.Content = params.get("Content")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MessageBody(AbstractModel):
@@ -725,6 +1010,89 @@ class MessageBody(AbstractModel):
                 obj = Message()
                 obj._deserialize(item)
                 self.Messages.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class PSTNSession(AbstractModel):
+    """PSTN 会话类型。
+
+    """
+
+    def __init__(self):
+        """
+        :param SessionID: 会话 ID
+        :type SessionID: str
+        :param RoomID: 会话临时房间 ID
+        :type RoomID: str
+        :param Caller: 主叫
+        :type Caller: str
+        :param Callee: 被叫
+        :type Callee: str
+        :param StartTimestamp: 开始时间，Unix 时间戳
+        :type StartTimestamp: int
+        :param RingTimestamp: 振铃时间，Unix 时间戳
+        :type RingTimestamp: int
+        :param AcceptTimestamp: 接听时间，Unix 时间戳
+        :type AcceptTimestamp: int
+        :param StaffEmail: 坐席邮箱
+        :type StaffEmail: str
+        :param StaffNumber: 坐席工号
+        :type StaffNumber: str
+        :param SessionStatus: 会话状态
+ringing 振铃中
+seatJoining  等待坐席接听
+inProgress 进行中
+finished 已完成
+        :type SessionStatus: str
+        :param Direction: 会话呼叫方向， 0 呼入 | 1 - 呼出
+        :type Direction: int
+        :param OutBoundCaller: 转外线使用的号码（转外线主叫）
+        :type OutBoundCaller: str
+        :param OutBoundCallee: 转外线被叫
+        :type OutBoundCallee: str
+        """
+        self.SessionID = None
+        self.RoomID = None
+        self.Caller = None
+        self.Callee = None
+        self.StartTimestamp = None
+        self.RingTimestamp = None
+        self.AcceptTimestamp = None
+        self.StaffEmail = None
+        self.StaffNumber = None
+        self.SessionStatus = None
+        self.Direction = None
+        self.OutBoundCaller = None
+        self.OutBoundCallee = None
+
+
+    def _deserialize(self, params):
+        self.SessionID = params.get("SessionID")
+        self.RoomID = params.get("RoomID")
+        self.Caller = params.get("Caller")
+        self.Callee = params.get("Callee")
+        self.StartTimestamp = params.get("StartTimestamp")
+        self.RingTimestamp = params.get("RingTimestamp")
+        self.AcceptTimestamp = params.get("AcceptTimestamp")
+        self.StaffEmail = params.get("StaffEmail")
+        self.StaffNumber = params.get("StaffNumber")
+        self.SessionStatus = params.get("SessionStatus")
+        self.Direction = params.get("Direction")
+        self.OutBoundCaller = params.get("OutBoundCaller")
+        self.OutBoundCallee = params.get("OutBoundCallee")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PSTNSessionInfo(AbstractModel):
@@ -782,6 +1150,13 @@ class PSTNSessionInfo(AbstractModel):
         self.SessionStatus = params.get("SessionStatus")
         self.Direction = params.get("Direction")
         self.RingTimestamp = params.get("RingTimestamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SeatUserInfo(AbstractModel):
@@ -825,6 +1200,13 @@ class SeatUserInfo(AbstractModel):
         self.UserId = params.get("UserId")
         self.SkillGroupNameList = params.get("SkillGroupNameList")
         self.StaffNumber = params.get("StaffNumber")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ServeParticipant(AbstractModel):
@@ -918,6 +1300,13 @@ class ServeParticipant(AbstractModel):
         self.Sequence = params.get("Sequence")
         self.StartTimestamp = params.get("StartTimestamp")
         self.SkillGroupName = params.get("SkillGroupName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SkillGroupInfoItem(AbstractModel):
@@ -963,6 +1352,13 @@ class SkillGroupInfoItem(AbstractModel):
         self.UsingLastSeat = params.get("UsingLastSeat")
         self.MaxConcurrency = params.get("MaxConcurrency")
         self.LastModifyTimestamp = params.get("LastModifyTimestamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SkillGroupItem(AbstractModel):
@@ -992,6 +1388,13 @@ class SkillGroupItem(AbstractModel):
         self.SkillGroupName = params.get("SkillGroupName")
         self.Priority = params.get("Priority")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StaffInfo(AbstractModel):
@@ -1044,6 +1447,13 @@ class StaffInfo(AbstractModel):
                 obj._deserialize(item)
                 self.SkillGroupList.append(obj)
         self.LastModifyTimestamp = params.get("LastModifyTimestamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TelCdrInfo(AbstractModel):
@@ -1155,6 +1565,9 @@ notInService       不在服务区
         :param QueuedSkillGroupId: 排队技能组Id
 注意：此字段可能返回 null，表示取不到有效值。
         :type QueuedSkillGroupId: int
+        :param SessionId: 会话 ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SessionId: str
         """
         self.Caller = None
         self.Callee = None
@@ -1179,6 +1592,7 @@ notInService       不在服务区
         self.QueuedTimestamp = None
         self.PostIVRKeyPressed = None
         self.QueuedSkillGroupId = None
+        self.SessionId = None
 
 
     def _deserialize(self, params):
@@ -1216,4 +1630,61 @@ notInService       不在服务区
                 obj = IVRKeyPressedElement()
                 obj._deserialize(item)
                 self.PostIVRKeyPressed.append(obj)
-        self.QueuedSkillGroupId = params.get("QueuedSkillGroupId")
\ No newline at end of file
+        self.QueuedSkillGroupId = params.get("QueuedSkillGroupId")
+        self.SessionId = params.get("SessionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UnbindStaffSkillGroupListRequest(AbstractModel):
+    """UnbindStaffSkillGroupList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 实例ID
+        :type SdkAppId: int
+        :param StaffEmail: 客服邮箱
+        :type StaffEmail: str
+        :param SkillGroupList: 解绑技能组列表
+        :type SkillGroupList: list of int
+        """
+        self.SdkAppId = None
+        self.StaffEmail = None
+        self.SkillGroupList = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.StaffEmail = params.get("StaffEmail")
+        self.SkillGroupList = params.get("SkillGroupList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UnbindStaffSkillGroupListResponse(AbstractModel):
+    """UnbindStaffSkillGroupList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
