@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -222,6 +222,34 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def EncryptedPhoneVerification(self, request):
+        """本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持MD5加密传输。
+
+        :param request: Request instance for EncryptedPhoneVerification.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.EncryptedPhoneVerificationRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.EncryptedPhoneVerificationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("EncryptedPhoneVerification", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.EncryptedPhoneVerificationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetActionSequence(self, request):
         """使用动作活体检测模式前，需调用本接口获取动作顺序。
 
@@ -335,7 +363,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetEidToken(self, request):
-        """每次调用人脸核身小程序服务前，需先调用本接口获取EidToken，用来串联核身流程，在验证完成后，用于获取验证结果信息。
+        """每次调用E证通小程序服务前，需先调用本接口获取EidToken，用来串联核身流程，在验证完成后，用于获取验证结果信息。
 
         :param request: Request instance for GetEidToken.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetEidTokenRequest`
