@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class BankCard2EVerificationRequest(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.BankCard = params.get("BankCard")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BankCard2EVerificationResponse(AbstractModel):
@@ -119,6 +128,13 @@ class BankCard4EVerificationRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BankCard4EVerificationResponse(AbstractModel):
@@ -201,6 +217,13 @@ class BankCardVerificationRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BankCardVerificationResponse(AbstractModel):
@@ -263,6 +286,13 @@ class CheckBankCardInformationRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.BankCard = params.get("BankCard")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CheckBankCardInformationResponse(AbstractModel):
@@ -346,6 +376,13 @@ Config = {"CopyWarn":true,"ReshootWarn":true}
         self.ImageBase64 = params.get("ImageBase64")
         self.ImageUrl = params.get("ImageUrl")
         self.Config = params.get("Config")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CheckIdCardInformationResponse(AbstractModel):
@@ -441,6 +478,13 @@ class CheckPhoneAndNameRequest(AbstractModel):
     def _deserialize(self, params):
         self.Mobile = params.get("Mobile")
         self.Name = params.get("Name")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CheckPhoneAndNameResponse(AbstractModel):
@@ -522,6 +566,13 @@ Base64编码后的图片数据大小不超过3M，仅支持jpg、png格式。请
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectAuthResponse(AbstractModel):
@@ -630,6 +681,13 @@ class DetectDetail(AbstractModel):
         self.Comparestatus = params.get("Comparestatus")
         self.Comparemsg = params.get("Comparemsg")
         self.CompareLibType = params.get("CompareLibType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectInfoBestFrame(AbstractModel):
@@ -653,6 +711,13 @@ class DetectInfoBestFrame(AbstractModel):
     def _deserialize(self, params):
         self.BestFrame = params.get("BestFrame")
         self.BestFrames = params.get("BestFrames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectInfoIdCardData(AbstractModel):
@@ -691,6 +756,13 @@ class DetectInfoIdCardData(AbstractModel):
         self.ProcessedFrontImage = params.get("ProcessedFrontImage")
         self.ProcessedBackImage = params.get("ProcessedBackImage")
         self.Avatar = params.get("Avatar")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectInfoText(AbstractModel):
@@ -823,6 +895,13 @@ class DetectInfoText(AbstractModel):
                 self.LivenessDetail.append(obj)
         self.Mobile = params.get("Mobile")
         self.CompareLibType = params.get("CompareLibType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectInfoVideoData(AbstractModel):
@@ -841,6 +920,13 @@ class DetectInfoVideoData(AbstractModel):
 
     def _deserialize(self, params):
         self.LivenessVideo = params.get("LivenessVideo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EidInfo(AbstractModel):
@@ -862,6 +948,13 @@ class EidInfo(AbstractModel):
     def _deserialize(self, params):
         self.EidCode = params.get("EidCode")
         self.EidSign = params.get("EidSign")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EncryptedPhoneVerificationRequest(AbstractModel):
@@ -894,6 +987,13 @@ class EncryptedPhoneVerificationRequest(AbstractModel):
         self.Name = params.get("Name")
         self.Phone = params.get("Phone")
         self.EncryptionMode = params.get("EncryptionMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EncryptedPhoneVerificationResponse(AbstractModel):
@@ -952,6 +1052,13 @@ class Encryption(AbstractModel):
         self.CiphertextBlob = params.get("CiphertextBlob")
         self.EncryptList = params.get("EncryptList")
         self.Iv = params.get("Iv")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetActionSequenceRequest(AbstractModel):
@@ -969,6 +1076,13 @@ class GetActionSequenceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ActionType = params.get("ActionType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetActionSequenceResponse(AbstractModel):
@@ -1033,6 +1147,13 @@ class GetDetectInfoEnhancedRequest(AbstractModel):
         self.IsCutIdCardImage = params.get("IsCutIdCardImage")
         self.IsNeedIdCardAvatar = params.get("IsNeedIdCardAvatar")
         self.IsEncrypt = params.get("IsEncrypt")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetDetectInfoEnhancedResponse(AbstractModel):
@@ -1112,6 +1233,13 @@ class GetDetectInfoRequest(AbstractModel):
         self.BizToken = params.get("BizToken")
         self.RuleId = params.get("RuleId")
         self.InfoType = params.get("InfoType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetDetectInfoResponse(AbstractModel):
@@ -1208,6 +1336,13 @@ class GetEidResultRequest(AbstractModel):
         self.EidToken = params.get("EidToken")
         self.InfoType = params.get("InfoType")
         self.BestFramesCount = params.get("BestFramesCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEidResultResponse(AbstractModel):
@@ -1276,6 +1411,13 @@ class GetEidTokenConfig(AbstractModel):
 
     def _deserialize(self, params):
         self.InputType = params.get("InputType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEidTokenRequest(AbstractModel):
@@ -1285,14 +1427,14 @@ class GetEidTokenRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param MerchantId: EID商户id
+        :param MerchantId: EID商户id，字段长度最长50位。
         :type MerchantId: str
         :param IdCard: 身份标识（未使用OCR服务时，必须传入）。
 规则：a-zA-Z0-9组合。最长长度32位。
         :type IdCard: str
         :param Name: 姓名。（未使用OCR服务时，必须传入）最长长度32位。中文请使用UTF-8编码。
         :type Name: str
-        :param Extra: 透传字段，在获取验证结果时返回。
+        :param Extra: 透传字段，在获取验证结果时返回。最长长度1024位。
         :type Extra: str
         :param Config: 小程序模式配置，包括如何传入姓名身份证的配置。
         :type Config: :class:`tencentcloud.faceid.v20180301.models.GetEidTokenConfig`
@@ -1312,6 +1454,13 @@ class GetEidTokenRequest(AbstractModel):
         if params.get("Config") is not None:
             self.Config = GetEidTokenConfig()
             self.Config._deserialize(params.get("Config"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetEidTokenResponse(AbstractModel):
@@ -1359,6 +1508,13 @@ class GetFaceIdResultRequest(AbstractModel):
         self.FaceIdToken = params.get("FaceIdToken")
         self.IsNeedVideo = params.get("IsNeedVideo")
         self.IsNeedBestFrame = params.get("IsNeedBestFrame")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetFaceIdResultResponse(AbstractModel):
@@ -1449,6 +1605,13 @@ class GetFaceIdTokenRequest(AbstractModel):
         self.ImageBase64 = params.get("ImageBase64")
         self.Meta = params.get("Meta")
         self.Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetFaceIdTokenResponse(AbstractModel):
@@ -1514,6 +1677,13 @@ class GetRealNameAuthResultRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AuthToken = params.get("AuthToken")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetRealNameAuthResultResponse(AbstractModel):
@@ -1568,6 +1738,13 @@ class GetRealNameAuthTokenRequest(AbstractModel):
         self.Name = params.get("Name")
         self.IDCard = params.get("IDCard")
         self.CallbackURL = params.get("CallbackURL")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetRealNameAuthTokenResponse(AbstractModel):
@@ -1635,6 +1812,13 @@ class IdCardOCRVerificationRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IdCardOCRVerificationResponse(AbstractModel):
@@ -1717,6 +1901,13 @@ class IdCardVerificationRequest(AbstractModel):
     def _deserialize(self, params):
         self.IdCard = params.get("IdCard")
         self.Name = params.get("Name")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IdCardVerificationResponse(AbstractModel):
@@ -1781,6 +1972,13 @@ Base64编码后的图片数据大小不超过3M，仅支持jpg、png格式。
         self.Name = params.get("Name")
         self.ImageBase64 = params.get("ImageBase64")
         self.Optional = params.get("Optional")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageRecognitionResponse(AbstractModel):
@@ -1830,13 +2028,13 @@ Base64编码后的大小不超过8M，支持mp4、avi、flv格式。
         :param LivenessType: 活体检测类型，取值：LIP/ACTION/SILENT。
 LIP为数字模式，ACTION为动作模式，SILENT为静默模式，三种模式选择一种传入。
         :type LivenessType: str
-        :param ValidateData: 数字模式传参：数字验证码(1234)，需先调用接口获取数字验证码；
-动作模式传参：传动作顺序(2,1 or 1,2)，需先调用接口获取动作顺序；
+        :param ValidateData: 数字模式传参：传数字验证码，验证码需先调用<a href="https://cloud.tencent.com/document/product/1007/31821">获取数字验证码接口</a>得到；
+动作模式传参：传动作顺序，动作顺序需先调用<a href="https://cloud.tencent.com/document/product/1007/31822">获取动作顺序接口</a>得到；
 静默模式传参：空。
         :type ValidateData: str
         :param Optional: 额外配置，传入JSON字符串。
 {
-"BestFrameNum": 2  //需要返回多张最佳截图，取值范围1-10
+"BestFrameNum": 2  //需要返回多张最佳截图，取值范围2-10
 }
         :type Optional: str
         """
@@ -1853,6 +2051,13 @@ LIP为数字模式，ACTION为动作模式，SILENT为静默模式，三种模
         self.LivenessType = params.get("LivenessType")
         self.ValidateData = params.get("ValidateData")
         self.Optional = params.get("Optional")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LivenessCompareResponse(AbstractModel):
@@ -1911,13 +2116,13 @@ BASE64编码后的大小不超过8M，支持mp4、avi、flv格式。
         :param LivenessType: 活体检测类型，取值：LIP/ACTION/SILENT。
 LIP为数字模式，ACTION为动作模式，SILENT为静默模式，三种模式选择一种传入。
         :type LivenessType: str
-        :param ValidateData: 数字模式传参：数字验证码(1234)，需先调用接口获取数字验证码；
-动作模式传参：传动作顺序(2,1 or 1,2)，需先调用接口获取动作顺序；
+        :param ValidateData: 数字模式传参：传数字验证码，验证码需先调用<a href="https://cloud.tencent.com/document/product/1007/31821">获取数字验证码接口</a>得到；
+动作模式传参：传动作顺序，动作顺序需先调用<a href="https://cloud.tencent.com/document/product/1007/31822">获取动作顺序接口</a>得到；
 静默模式传参：空。
         :type ValidateData: str
         :param Optional: 额外配置，传入JSON字符串。
 {
-"BestFrameNum": 2  //需要返回多张最佳截图，取值范围1-10
+"BestFrameNum": 2  //需要返回多张最佳截图，取值范围2-10
 }
         :type Optional: str
         """
@@ -1936,6 +2141,13 @@ LIP为数字模式，ACTION为动作模式，SILENT为静默模式，三种模
         self.LivenessType = params.get("LivenessType")
         self.ValidateData = params.get("ValidateData")
         self.Optional = params.get("Optional")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LivenessRecognitionResponse(AbstractModel):
@@ -2011,6 +2223,13 @@ LIP为数字模式，ACTION为动作模式，SILENT为静默模式，三种模
         self.LivenessType = params.get("LivenessType")
         self.ValidateData = params.get("ValidateData")
         self.Optional = params.get("Optional")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LivenessResponse(AbstractModel):
@@ -2085,6 +2304,13 @@ class MinorsVerificationRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MinorsVerificationResponse(AbstractModel):
@@ -2153,6 +2379,13 @@ class MobileNetworkTimeVerificationRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MobileNetworkTimeVerificationResponse(AbstractModel):
@@ -2213,6 +2446,13 @@ class MobileStatusRequest(AbstractModel):
         if params.get("Encryption") is not None:
             self.Encryption = Encryption()
             self.Encryption._deserialize(params.get("Encryption"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MobileStatusResponse(AbstractModel):
@@ -2291,6 +2531,13 @@ class PhoneVerificationRequest(AbstractModel):
         self.CiphertextBlob = params.get("CiphertextBlob")
         self.EncryptList = params.get("EncryptList")
         self.Iv = params.get("Iv")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PhoneVerificationResponse(AbstractModel):
